package org.rcisoft.bus.jnsp7xtm.service.impl;

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.rcisoft.bus.jnsp7xtm.dao.Jnsp7xtmDtoRepository;
import org.rcisoft.bus.jnsp7xtm.dao.Jnsp7xtmRepository;
import org.rcisoft.bus.jnsp7xtm.entity.ExportTotalDto;
import org.rcisoft.bus.jnsp7xtm.entity.RequestInfromationDto;
import org.rcisoft.bus.jnsp7xtm.entity.RoleDto;
import org.rcisoft.bus.jnsp7xtm.vo.QueryJnsp7xtmDto;
import org.rcisoft.util.ExcelExportStatisticStyler;
import org.rcisoft.util.ExportToExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Author: gy
 * @Date: 2024/4/29 13:10
 * @Description: 导出service 层
 */
@Service
@Slf4j
public class ExportExcelService {

    @Autowired
    private Jnsp7xtmDtoRepository jnsp7xtmDtoRepository;

    @Autowired
    private Jnsp7xtmRepository jnsp7xtmRepository;

    // 获取每次写入excel的长度
    @Value("${export.size}")
    private Integer size;

    // 导出明细
    public void outJnsp7xtmDetail(HttpServletResponse response, QueryJnsp7xtmDto jnsp7xtm,String excelName) {
        // 获取数组总长度
        Integer total = jnsp7xtmDtoRepository.queryTotal(jnsp7xtm);
        if (total > 0) {
            // 获取有几页
            Integer pageNumber = 1;
            if (total >= size) {
                pageNumber = total/size;
            }
           // 获取exportParams
            ExportParams exportParams = new ExportParams();
            exportParams.setStyle(ExcelExportStatisticStyler.class);
            String[] format = excelName.split("\\.");
            if (format[1].equals("xlsx")) {
                exportParams.setType(ExcelType.XSSF);
            }
            Workbook workbook = bigExcel(pageNumber, exportParams, null, jnsp7xtm);
            ExcelExportUtil.closeExportBigExcel();
            ExportToExcelUtil.downLoadExcel(excelName,response,workbook);
        } else {
            IPage<RoleDto> page = new Page<>(1,size);
            IPage<RoleDto> dtoIPage = jnsp7xtmDtoRepository.queryFindAllList(page, jnsp7xtm);
            List<RoleDto> records = dtoIPage.getRecords();
            ExportToExcelUtil.exportExcel(records, "明细信息", "明细信息", RoleDto.class, excelName, response);
        }
    }

    public Workbook bigExcel(Integer pageNumber,ExportParams exportParams,  Workbook workbook,QueryJnsp7xtmDto jnsp7xtm) {
        for (int i = 1; i <= pageNumber; i++) {
            IPage<RoleDto> page = new Page<>(i,size);
            IPage<RoleDto> dtoIPage = jnsp7xtmDtoRepository.queryFindAllList(page, jnsp7xtm);
            List<RoleDto> records = dtoIPage.getRecords();
            workbook = ExcelExportUtil.exportBigExcel(exportParams, RoleDto.class, records);
        }
        return workbook;
    }

    public void outUserJnsp7xtmDetail(HttpServletResponse response,RequestInfromationDto requestInfromationDto,String excelName) {
        //设置查询值
        String key = requestInfromationDto.getClickKey();
        RequestInfromationDto.cleanAndBuild(requestInfromationDto, key);
        Integer total = jnsp7xtmRepository.queryTotal(requestInfromationDto);
        if (total > 0) {
            Integer pageNumber = 1;
            if (total >= size) {
                pageNumber = total/size;
            }
            // 获取exportParams
            ExportParams exportParams = new ExportParams();
            exportParams.setStyle(ExcelExportStatisticStyler.class);
            String[] format = excelName.split("\\.");
            if (format[1].equals("xlsx")) {
                exportParams.setType(ExcelType.XSSF);
            }
            Workbook workbook = jnsp7xtmBigExcel(pageNumber, exportParams, null, requestInfromationDto);
            ExcelExportUtil.closeExportBigExcel();
            ExportToExcelUtil.downLoadExcel(excelName,response,workbook);

        } else {
            IPage<RoleDto> page = new Page<>(1,size);
            IPage<RoleDto> dtoIPage = jnsp7xtmRepository.pagingQueryAllInformation(page, requestInfromationDto);
            List<RoleDto> records = dtoIPage.getRecords();
            ExportToExcelUtil.exportExcel(records, "详细信息", "详细信息", RoleDto.class, excelName, response);
        }

    }

    public Workbook jnsp7xtmBigExcel(Integer pageNumber,ExportParams exportParams,  Workbook workbook,RequestInfromationDto requestInfromationDto){
        for (int i = 1; i <= pageNumber; i++) {
            IPage<RoleDto> page = new Page<>(i,size);
            IPage<RoleDto> dtoIPage = jnsp7xtmRepository.pagingQueryAllInformation(page, requestInfromationDto);
            List<RoleDto> records = dtoIPage.getRecords();
            workbook = ExcelExportUtil.exportBigExcel(exportParams, RoleDto.class, records);
        }
        return workbook;
    }

}
