package org.rcisoft.bus.jnsp7xtm.service.impl;

import cn.afterturn.easypoi.excel.entity.params.ExcelExportEntity;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.util.LittleEndian;
import org.rcisoft.bus.jnsp7xtm.entity.*;
import org.rcisoft.bus.jnsp7xtm.dao.Jnsp7xtmRepository;
import org.rcisoft.bus.jnsp7xtm.service.Jnsp7xtmService;

import org.rcisoft.bus.jnsp7xtm.vo.ReturntTotalDto;
import org.rcisoft.bus.jnsp7xtm.vo.StatisticsDto;
import org.rcisoft.bus.jnsp7xtm.vo.TableHeader;
import org.rcisoft.util.ExportToExcelUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.security.Key;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年4月16日 下午5:29:36.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class Jnsp7xtmServiceImpl extends ServiceImpl<Jnsp7xtmRepository, Map> implements Jnsp7xtmService {

    // 查询下拉框
    @Override
    public Map<String, List<String>> searchOption() {
        Map<String,List<String>> optionList = new HashMap<>();
        // 查询 jpm下拉数据
        List<String> jLpmOptionList = baseMapper.jLpmOptionList();
        optionList.put("jlpm",jLpmOptionList);
        List<String> zdOptionList = baseMapper.zdOptionList();
        optionList.put("zd",zdOptionList);
        List<String> fnqOptionList = baseMapper.fnqOptionList();
        optionList.put("fnq",fnqOptionList);
        List<String> szztOptionList = baseMapper.szztOptionList();
        optionList.put("szzt",szztOptionList);
        // mksqf
        List<RoleDto> roleDtos = baseMapper.searchMksqf();
        List<String> mysqfOption = roleDtos.stream().map(RoleDto::getMksqf).collect(Collectors.toList());
        optionList.put("mysqf",mysqfOption);
        return optionList;
    }

    // 查询高级搜索
    @Override
    public Map<String, List<RoleDto>> searchHeightOption() {
        Map<String,List<RoleDto>> optionList = new HashMap<>();
        // khdm
        List<RoleDto> khdmList = baseMapper.searchKhdm();
        optionList.put("khdm",khdmList);
        // khm
        List<RoleDto> khmList = baseMapper.searchKhm();
        optionList.put("khm",khmList);
        // pn
        List<RoleDto> pnList = baseMapper.searchPn();
        optionList.put("pn",pnList);
        return optionList;
    }


    @Override
    public List<UserDto> getList(RequestDto requestDto) {
        // 返回值
        List<UserDto> userDtos = new ArrayList<>();
        // 判断数据库的数据是否为空 是否需要前端判断
        if (baseMapper.queryNUmber() == 0) {
            return userDtos;
        }
        //判断查询条件是否为全空
        boolean conditionIsNull =
                requestDto.isRmb() ||
                        requestDto.isXsjg() ||
                        requestDto.isCount() || requestDto.isChzs() || requestDto.isChzsa() || requestDto.isChzsb() || requestDto.isZzc() || requestDto.isZzcg();


        //没有选择默认选一个
        if (!conditionIsNull) {
            requestDto.setChzs(true);
        }
        //查询月份
        List<String> monthsList = baseMapper.getMonths();
        String months = monthsList.stream()
                // 将每个月份拼接成形如 "[yyyyMM]" 的字符串
                .map(month -> "[" + month + "]")
                // 使用逗号连接每个月份字符串
                .collect(Collectors.joining(","));
        // 初始化 listrmb 和 listxsjg 的值
        List<Map> listrmb = null;
        List<Map> listxsjg = null;
        List<Map> listChzs = null;
        List<Map> listChzsA = null;
        List<Map> listChzsB = null;
        List<Map> listzzc = null;
        List<Map> listzzcg = null;
        //页数
        Integer pageNo = requestDto.getPageNo();
        //每页大小
        Integer pageSize = requestDto.getPageSize();
        //默认查三个
        //定义变量进行存储
        int count = 0;
        boolean[] flag = new boolean[]{false, false,false,false,false,false,false};
        if (requestDto.isXsjg()) {
            listxsjg = baseMapper.getListxsjg(requestDto, months, pageNo, pageSize);
            count++;
            flag[0] = true;
        }
//        }
        if (requestDto.isRmb()) {
            listrmb = baseMapper.getListrmb(requestDto, months, pageNo, pageSize);
            count++;
            flag[1] = true;
        }
        if (requestDto.isChzs()) {
            listChzs = baseMapper.getListchzs(requestDto,months,pageNo,pageSize);
            count++;
            flag[2] = true;
        }
        if (requestDto.isChzsa()) {
            listChzsA = baseMapper.getListChzsaA(requestDto,months,pageNo,pageSize);
            count++;
            flag[3] = true;
        }
        if (requestDto.isChzsb()) {
            listChzsB = baseMapper.getListChzsaB(requestDto,months,pageNo,pageSize);
            count++;
            flag[4] = true;
        }
        if (requestDto.isZzc()) {
            listzzc =  baseMapper.getListzzc(requestDto,months,pageNo,pageSize);
            count++;
            flag[5] = true;
        }
        if (requestDto.isZzcg()) {
            listzzcg = baseMapper.getListzzcg(requestDto,months,pageNo,pageSize);
            count++;
            flag[6] = true;
        }
        int size = 0;
        //获得返回数据长度

        if (listrmb != null) {
            size = listrmb.size();
        } else if (listxsjg != null){
            size = listxsjg.size();
        } else if (listChzs != null) {
            size = listChzs.size();
        } else if (listChzsA != null) {
            size = listChzsA.size();
        } else if (listChzsB != null) {
            size = listChzsB.size();
        } else if (listzzc != null) {
            size = listzzc.size();
        } else if (listzzcg != null) {
            size = listzzcg.size();
        }

        //获取对应关系
        Map<String, UserDto> map = new HashMap();
        //创建填充数据
        List<UserDto> resList = new ArrayList<>();
        //真正的反参
        List<Map<String, String>> resMapList = new ArrayList<>();
        //获取日期参数
        List<String> nqy = requestDto.getNqy();
        //判断是否传入日期参数，如果没传入设置默认值
        if (nqy == null || nqy.size() == 0) {
            nqy = monthsList;
        }
        //填充返回数据
        for (int i = 0; i < size; i++) {
            if (listChzs != null) {
                getObjectByMap(listChzs,i,map,nqy,flag,resList,"CHZS");
            }
            //填充三种数据
            if (listrmb != null) {
                getObjectByMap(listrmb,i,map,nqy,flag,resList,"RMB");
            }
            if (listxsjg != null) {
                getObjectByMap(listxsjg,i,map,nqy,flag,resList,"XSJG");
            }
            if (listChzsA != null) {
                getObjectByMap(listChzsA,i,map,nqy,flag,resList,"CHZSA");
            }
            if (listChzsB != null) {
                getObjectByMap(listChzsB,i,map,nqy,flag,resList,"CHZSB");
            }
            if (listzzc != null) {
                getObjectByMap(listzzc,i,map,nqy,flag,resList,"ZZC");
            }
            if (listzzcg != null) {
                getObjectByMap(listzzcg,i,map,nqy,flag,resList,"ZZCG");
            }
            // 把resList赋给resMapList
            // 遍历resList，将每个Jnsp7xtmDto对象转换为Map对象，并添加到resMapList中
            for (UserDto userDto : resList) {
                List<Map<String, String>> mapListTemp = new ArrayList<>();
                // 遍历 userDto.getData() ,将userDto.getData() 中包含的数据添加到 data2 中
                for (Jnsp7xtmDto jnsp7xtmDto : userDto.getData()) {
                    Map<String, String> mapTemp = new LinkedHashMap<>();
                    mapTemp.put("nqy", jnsp7xtmDto.getNqy());
                    // 判断rmb是否需要,需要放入data中
                    if (requestDto.isXsjg()) {
                        mapTemp.put("xsjg", jnsp7xtmDto.getXsjg());
                    }
                    if (requestDto.isRmb()) {
                        mapTemp.put("rmb", jnsp7xtmDto.getRmb());
                    }
                    if (requestDto.isCount()) {
                        RequestInfromationDto requestInfromationDto = new RequestInfromationDto();
                        //
                        requestInfromationDto.setClickKhdm(userDto.getKhdm());
                        requestInfromationDto.setClickKey("nqy");
                        requestInfromationDto.setClickNqy(jnsp7xtmDto.getNqy());
                        requestInfromationDto.setClickValue(jnsp7xtmDto.getNqy());
                        requestInfromationDto.setDdh(new ArrayList<>());
                        requestInfromationDto.setKhm(new ArrayList<>());
                        requestInfromationDto.setKhqf(new ArrayList<>());
                        requestInfromationDto.setMksqf(new ArrayList<>());
                        requestInfromationDto.setNqy(new ArrayList<>());
                        requestInfromationDto.setPn(new ArrayList<>());
                        String a = this.getClickInformationPageNum(requestInfromationDto);
                        if ("0".equals(a)) {
                            a = "";
                        }
                        mapTemp.put("count", a);
                        jnsp7xtmDto.setCount(a);
                    }
                    mapListTemp.add(mapTemp);
                }
                userDto.setData2(mapListTemp);

            }

        }
        return resList;
    }

    @Override
    public List<RoleDto> getInformation(RequestInfromationDto requestInfromationDto) {

        //设置查询值
        String key = requestInfromationDto.getClickKey();
        RequestInfromationDto.cleanAndBuild(requestInfromationDto, key);

        //单独查询
        List<RoleDto> data = baseMapper.getInformation(requestInfromationDto);

        return data;
    }

    @Override
    public List<RoleDto> getInAllformation(RequestInfromationDto requestInfromationDto) {
        //设置查询值
        String key = requestInfromationDto.getClickKey();
        RequestInfromationDto.cleanAndBuild(requestInfromationDto, key);
        List<RoleDto> data = baseMapper.getAllInformation(requestInfromationDto);
        return data;
    }

    @Override
    public Integer getListTotal(RequestDto requestDto) {
        if (baseMapper.queryNUmber() == 0) {
            return 0;
        }
        boolean conditionIsNull =
                requestDto.isRmb() ||
                        requestDto.isXsjg() ||
                        requestDto.isCount() || requestDto.isChzs() || requestDto.isChzsa() || requestDto.isChzsb() || requestDto.isZzc() ||requestDto.isZzcg();


        //没有选择默认选一个
        if (!conditionIsNull) {
            requestDto.setChzs(true);
        }
        //查询月份
        List<String> monthsList = baseMapper.getMonths();

        String months = monthsList.stream()
                .map(month -> "[" + month + "]")

                .collect(Collectors.joining(","));


        List<Map<String,Object>> temp = null;
        //获得返回数据长度
        if (requestDto.isRmb()) {
            temp = baseMapper.getExportListrmb(requestDto, months);
        }
        if(requestDto.isXsjg()) {
            temp = baseMapper.getExportListxsjg(requestDto, months);
        }
        if (requestDto.isChzs()) {
           temp = baseMapper.getExportListChzsaAndchzsb(requestDto,months);
        }
        if(requestDto.isChzsa()) {
           temp = baseMapper.getExportListChzsaA(requestDto,months);
        }
        if (requestDto.isChzsb()) {
           temp = baseMapper.getExportListChzsaB(requestDto,months);
        }
        if (requestDto.isZzc()) {
           temp = baseMapper.getExportListZzc(requestDto,months);
        }
        if (requestDto.isZzcg()) {
            temp = baseMapper.getExportListZzcg(requestDto,months);
        }
        return temp.size();
    }

    @Override
    public String getClickInformationPageNum(RequestInfromationDto requestInfromationDto) {
        //设置查询值
        String key = requestInfromationDto.getClickKey();
        RequestInfromationDto.cleanAndBuild(requestInfromationDto, key);

        //单独查询
        String data = baseMapper.getClickInformationPageNum(requestInfromationDto);

        return String.valueOf(data);
    }

    @Override
    public ReturntTotalDto getTotal(RequestDto requestDto) {
        // 查询数据中是否有数据
        ReturntTotalDto returntTotalDto = new ReturntTotalDto();
        //判断查询条件是否为全空
        boolean conditionIsNull =
                requestDto.isRmb() ||
                        requestDto.isXsjg() ||
                        requestDto.isCount() || requestDto.isChzs() || requestDto.isChzsa() || requestDto.isChzsb() || requestDto.isZzc() || requestDto.isZzcg();
        //没有选择默认选一个
        if (!conditionIsNull) {
            requestDto.setChzs(true);
        }
        // 获取月份
        //查询月份
        List<String> monthsList = baseMapper.getMonths();
        List<String> nqyList = new ArrayList<>();
        List<Jnsp7xtmDto> jnsp7xtmDtos = new ArrayList<>();
        if (requestDto.getNqy().isEmpty()) {
            requestDto.setNqy(monthsList);
        }
        List<StatisticsDto> statisticsDtos = baseMapper.queryStatistics(requestDto);
        if (!statisticsDtos.isEmpty()) {
            statisticsDtos.forEach(item -> {
                Jnsp7xtmDto dto = new Jnsp7xtmDto();
                dto.setNqy(item.getNqy());
                nqyList.add(item.getNqy());
                if (item.getXsjg() != null) {
                    dto.setXsjg(String.valueOf(item.getXsjg()));
                }
                if (item.getRmb() != null) {
                    dto.setRmb(String.valueOf(item.getRmb()));
                }
                if (item.getNumber() != null) {
                    dto.setCount(String.valueOf(item.getNumber()));
                }
                if (item.getChzs() != null) {
                    dto.setChzs(String.valueOf(item.getChzs()));
                }
                if (item.getChzsa() != null) {
                    dto.setChzsa(String.valueOf(item.getChzsa()));
                }
                if (item.getChzsb() != null) {
                    dto.setChzsb(String.valueOf(item.getChzsb()));
                }
                if (item.getZzc() != null) {
                    dto.setZzc(String.valueOf(item.getZzc()));
                }
                if (item.getZzcg() != null) {
                    dto.setZzcg(String.valueOf(item.getZzcg()));
                }
              jnsp7xtmDtos.add(dto);
            });

        }
        if (!jnsp7xtmDtos.isEmpty()) {
            Jnsp7xtmDto jnsp7xtmDto = new Jnsp7xtmDto();
            BeanUtils.copyProperties(jnsp7xtmDtos.get(0),jnsp7xtmDto);
            if (jnsp7xtmDto.getXsjg() != null) {
                jnsp7xtmDto.setXsjg("");
            }
            if (jnsp7xtmDto.getRmb() != null) {
                jnsp7xtmDto.setRmb("");
            }
            if (jnsp7xtmDto.getChzs() != null) {
                jnsp7xtmDto.setChzs("");
            }
            if (jnsp7xtmDto.getChzsa() != null) {
                jnsp7xtmDto.setChzsa("");
            }
            if (jnsp7xtmDto.getChzsb() != null) {
                jnsp7xtmDto.setChzsb("");
            }
            if (jnsp7xtmDto.getZzc() != null) {
                jnsp7xtmDto.setZzc("");
            }
            if (jnsp7xtmDto.getZzcg() != null) {
                jnsp7xtmDto.setZzcg("");
            }
            List<String> filteredList = monthsList.stream()
                    .filter(month -> !nqyList.contains(month))
                    .collect(Collectors.toList());
            if (!filteredList.isEmpty()) {
                for (int i = 0; i < filteredList.size(); i++) {
                    Jnsp7xtmDto one = new Jnsp7xtmDto();
                    BeanUtils.copyProperties(jnsp7xtmDto,one);
                    one.setNqy(filteredList.get(i));
                    jnsp7xtmDtos.add(one);
                }
            }
        }
        // 处理返回值
        List<Jnsp7xtmDto> collect = jnsp7xtmDtos.stream().sorted(Comparator.comparing(Jnsp7xtmDto::getNqy)).collect(Collectors.toList());
        returntTotalDto.setJnsp7xtmDtos(collect);
        return returntTotalDto;
    }

    // 获取表头和数据集合
    @Override
    public ExportTotalDto outTotalJnsp7xtm(RequestDto requestDto) {
        ExportTotalDto exportTotalDto = new ExportTotalDto();
        //查询月份
        List<String> monthsList = baseMapper.getMonths();
        String months = monthsList.stream()
                // 将每个月份拼接成形如 "[yyyyMM]" 的字符串
                .map(month -> "[" + month + "]")
                // 使用逗号连接每个月份字符串
                .collect(Collectors.joining(","));
        List<TableHeader> tableHeaders = new ArrayList<>();
        List<TableHeader> sortTableHeaders = new ArrayList<>();
        List<TableHeader> chzsTableHeaders = new ArrayList<>();
        List<TableHeader> rmbTableHeaders = new ArrayList<>();
        List<TableHeader> xsjgTableHeaders = new ArrayList<>();
        List<TableHeader> chzsaTableHeaders = new ArrayList<>();
        List<TableHeader> chzsbTableHeaders = new ArrayList<>();
        List<TableHeader> zzcTableHeaders = new ArrayList<>();
        List<TableHeader> zzcgTableHeaders = new ArrayList<>();
        getTableHeadeList().stream().forEach(item -> {
            tableHeaders.add(item);
            chzsTableHeaders.add(item);
            rmbTableHeaders.add(item);
            xsjgTableHeaders.add(item);
            chzsaTableHeaders.add(item);
            chzsbTableHeaders.add(item);
            zzcTableHeaders.add(item);
            zzcgTableHeaders.add(item);
        });

        List<StatisticsDto> statisticsDtos = baseMapper.queryStatistics(requestDto);
        if (!statisticsDtos.isEmpty()) {
            statisticsDtos.forEach(item -> {
                if (item.getChzs() != null) {
                    TableHeader tableHeader = getTableHeader("chzs", item);
                    chzsTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getRmb() != null) {
                    TableHeader tableHeader = getTableHeader("rmb", item);
                    rmbTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getXsjg() != null) {
                    TableHeader tableHeader = getTableHeader("xsjg", item);
                    xsjgTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getChzsa() != null) {
                    TableHeader tableHeader = getTableHeader("chzsa", item);
                    chzsaTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getChzsb() != null) {
                    TableHeader tableHeader = getTableHeader("chzsb", item);
                    chzsbTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getZzc() != null) {
                    TableHeader tableHeader = getTableHeader("zzc", item);
                    zzcTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
                if (item.getZzcg() != null) {
                    TableHeader tableHeader = getTableHeader("zzcg", item);
                    zzcgTableHeaders.add(tableHeader);
                    sortTableHeaders.add(tableHeader);
                }
            });
        }
        List<TableHeader> tempList = sortTableHeaders.stream().sorted(Comparator.comparing(TableHeader::getOldKey)).collect(Collectors.toList());
        tempList.stream().forEach(item -> {
            tableHeaders.add(item);
        });
        List<ExcelExportEntity> entityList = new ArrayList<>();
        for (int i = 0; i < tableHeaders.size(); i++) {
            entityList.add(new ExcelExportEntity(tableHeaders.get(i).getName(), tableHeaders.get(i).getKey(), 20));
        }
        // 将对应的列传为数值
        for (int i = 0; i < entityList.size(); i++) {
            if (i > 1 && i < entityList.size()) {
                entityList.get(i).setType(10);
            }
        }
        List<Map<String, Object>> dataList = new ArrayList<>();
        // 获取要导出的条数
        List<Map<String, Object>> exportListCount = baseMapper.getExportListCount(requestDto, months);
        if (!exportListCount.isEmpty()) {
            for (int i = 0; i < exportListCount.size(); i++) {
                HashMap<String, Object> contentMap = new HashMap<>();
                if (requestDto.isChzs()) {
                    List<Map<String, Object>> exportListChzsaAndchzsb = baseMapper.getExportListChzsaAndchzsb(requestDto, months);
                    for (int j = 0; j < chzsTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListChzsaAndchzsb.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(chzsTableHeaders.get(j).getOldKey())) {
                                contentMap.put(chzsTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }

                if (requestDto.isRmb()) {
                    List<Map<String, Object>> exportListrmb = baseMapper.getExportListrmb(requestDto, months);
                    for (int j = 0; j < rmbTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListrmb.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(rmbTableHeaders.get(j).getOldKey())) {
                                contentMap.put(rmbTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }

                if (requestDto.isXsjg()) {
                    List<Map<String, Object>> exportListxsjg = baseMapper.getExportListxsjg(requestDto, months);
                    for (int j = 0; j < xsjgTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListxsjg.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(xsjgTableHeaders.get(j).getOldKey())) {
                                contentMap.put(xsjgTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }
                if (requestDto.isChzsa()) {
                    List<Map<String, Object>> exportListChzsaA = baseMapper.getExportListChzsaA(requestDto, months);
                    for (int j = 0; j < chzsaTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListChzsaA.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(chzsaTableHeaders.get(j).getOldKey())) {
                                contentMap.put(chzsaTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }
                if (requestDto.isChzsb()) {
                    List<Map<String, Object>> exportListChzsaB = baseMapper.getExportListChzsaB(requestDto, months);
                    for (int j = 0; j < chzsbTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListChzsaB.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(chzsbTableHeaders.get(j).getOldKey())) {
                                contentMap.put(chzsbTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }

                if (requestDto.isZzc()) {
                    List<Map<String, Object>> exportListZzc = baseMapper.getExportListZzc(requestDto, months);
                    for (int j = 0; j < zzcTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListZzc.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(zzcTableHeaders.get(j).getOldKey())) {
                                contentMap.put(zzcTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }
                if (requestDto.isZzcg()) {
                    List<Map<String, Object>> exportListZzcg = baseMapper.getExportListZzcg(requestDto, months);
                    for (int j = 0; j < zzcgTableHeaders.size(); j++) {
                        for (Map.Entry<String, Object> objectEntry : exportListZzcg.get(i).entrySet()) {
                            if (objectEntry.getKey().equals(zzcgTableHeaders.get(j).getOldKey())) {
                                contentMap.put(zzcgTableHeaders.get(j).getKey(), objectEntry.getValue());
                            }
                        }
                    }
                }

                dataList.add(contentMap);
            }
        }
        exportTotalDto.setEntityList(entityList);
        exportTotalDto.setDataList(dataList);
        return exportTotalDto;
    }

    @Override
    public boolean saveBatch(Collection<Map> entityList) {
        return super.saveBatch(entityList);
    }

    /**
     * @param entityList
     * @return
     */
    @Override
    public boolean saveOrUpdateBatch(Collection<Map> entityList) {
        return super.saveOrUpdateBatch(entityList);
    }

    public void getObjectByMap(List<Map> listrmb, int i,Map<String, UserDto> map,List<String> nqy,boolean[] flag,List<UserDto> resList,String tar) {
        Map listMap = listrmb.get(i);
        String khdm = (String) listMap.get("khdm");
        String khm = (String)listMap.get("khm");
        listMap.remove("khdm");
        listMap.remove("khm");
        UserDto userDto = map.getOrDefault(khdm.toString(), null);
        //判断该用户是否创建过
        if (userDto == null) {
            //创建对象加入到list结果中
            userDto = new UserDto(khm,khdm.toString(), nqy, flag);
            resList.add(userDto);
            map.put(khdm.toString(), userDto);
        }
        //获取到user中的Data数据
        List<Jnsp7xtmDto> data = userDto.getData();
        //获取月份对照集合
        Map<String, Integer> month = userDto.getMap();
        //set为键值对对象
        Set set = listMap.entrySet();
        for (Object o : set) {

            //强制转化为Entry对象
            Map.Entry<String, String> entry = (Map.Entry<String, String>) o;

            //获取到数据库中对应的月份
            String target = listMap.getOrDefault(entry.getKey(), null).toString();
            //不为空添加数据
            if (target != null) {
                //获取月份对应的下标
                Integer index = month.get(entry.getKey());
                //获取信息
                Jnsp7xtmDto jnsp7XtmDto = data.get(index);

                //原则上调用toString方法能解决，但是JIT自动优化了，只能使用上转型
                Object value = entry.getValue();
                if (tar.equals("CHZS")) {
                    jnsp7XtmDto.setChzs(String.valueOf(value));
                }
                if (tar.equals("RMB")) {
                    jnsp7XtmDto.setRmb(String.valueOf(value));
                }
                if (tar.equals("XSJG")){
                    jnsp7XtmDto.setXsjg(String.valueOf(value));
                }
                if (tar.equals("CHZSA")) {
                    jnsp7XtmDto.setChzsa(String.valueOf(value));
                }
                if (tar.equals("CHZSB")) {
                    jnsp7XtmDto.setChzsb(String.valueOf(value));
                }
                if (tar.equals("ZZC")) {
                    jnsp7XtmDto.setZzc(String.valueOf(value));
                }
                if (tar.equals("ZZCG")) {
                    jnsp7XtmDto.setZzcg(String.valueOf(value));
                }
            }
        }
    }

    public TableHeader getTableHeader(String tar,StatisticsDto item) {
        TableHeader tableHeader = new TableHeader();
        String key = item.getNqy() + "_" + tar;
        tableHeader.setName(key);
        tableHeader.setKey(key);
        tableHeader.setOldKey(item.getNqy());
        return tableHeader;
    }

    public List<TableHeader> getTableHeadeList() {
        List<TableHeader> list = new ArrayList<>();
        TableHeader oneTableHeader = new TableHeader();
        oneTableHeader.setName("用户id");
        oneTableHeader.setKey("khdm");
        oneTableHeader.setOldKey("khdm");
        list.add(oneTableHeader);
        TableHeader twoTableHeader = new TableHeader();
        twoTableHeader.setName("用户名称");
        twoTableHeader.setKey("khm");
        twoTableHeader.setOldKey("khm");
        list.add(twoTableHeader);
        return list;
    }

}





